package visiteur;

@Exercice(7)
public interface Visitor {
	/* Exo 3
	public void visit(Addition e);
	public void visit(Substraction e);
	public void visit(Division e);
	public void visit(Multiplication e);
	public void visit(Value e);
	public void visit(Variable e);
	*/
	
	public void visit(Expression e);
	
}
