package visiteur;

@Exercice(2)
public class Value extends AbstractExpression {
	private double value;
	
	public Value(int v){
		value=v;
	}

	/* Supprimé dans l'exo 7
	@Override
	public void accept(Visitor v) {
		v.visit(this);
	}
*/
	
	public double getValue() {
		return value;
	}
	
}
