package visiteur;

@Exercice(2)
public abstract class BinaryOp extends AbstractExpression {
	private Expression lChild;
	private Expression rChild;
	
	protected BinaryOp(Expression l,Expression r){
		lChild=l; rChild=r;
	}

	public Expression getLChild() {
		return lChild;
	}

	public Expression getRChild() {
		return rChild;
	}
	
}
