package visiteur;

@Exercice(2)
public class Substraction extends BinaryOp {

	public Substraction(Expression l, Expression r){
			super(l,r);
	}
	
	/* Supprimé dans l'exo 7
	@Override
	public void accept(Visitor v) {
		v.visit(this);
	}
	*/
}
