package visiteur;

public class UnassignedVariableException extends RuntimeException {
	private static final long serialVersionUID = 1L;

	public UnassignedVariableException(String m){
		super(m);
	}
	
}
